@@ -1,27 +1,10 @@
-/*  -- translated by f2c (version 20090411).
-   You must link the resulting object file with libf2c:
-	on Microsoft Windows system, link with libf2c.lib;
-	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
-	or, if you install libf2c.a in a standard place, with -lf2c -lm
-	-- in that order, at the end of the command line, as in
-		cc *.o -lf2c -lm
-	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
-
-		http://www.netlib.org/f2c/libf2c.zip
+/* src/grph2/uepack/uetonf.f -- translated by f2c (version 20020621).
+   You must link the resulting object file with the libraries:
+	-lf2c -lm   (in that order)
 */
 
 #include "libtinyf2c.h"
 
-/* Common Block Declarations */
-
-struct {
-    real tl1[100], tl2[100];
-    integer ipt[100], nt;
-    logical lascnd;
-} ueblk1_;
-
-#define ueblk1_1 ueblk1_
-
 /* ----------------------------------------------------------------------- */
 /*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
 /* ----------------------------------------------------------------------- */
@@ -68,7 +51,7 @@ struct {
 /*     / CHECK IMAGE CAPABILITY / */
     /* Parameter adjustments */
     z_dim1 = *mx;
-    z_offset = 1 + z_dim1;
+    z_offset = 1 + z_dim1 * 1;
     z__ -= z_offset;
 
     /* Function Body */
@@ -152,12 +135,7 @@ struct {
 				iy * z_dim1] * fx) * (1 - fy) + (z__[ix + (iy 
 				+ 1) * z_dim1] * (1 - fx) + z__[ix + 1 + (iy 
 				+ 1) * z_dim1] * fx) * fy;
-			if (ueblk1_1.tl1[0] <= zz && zz <= ueblk1_1.tl2[
-				ueblk1_1.nt - 1]) {
-			    image[i__ - 1] = iueton_(&zz) / 1000;
-			} else {
-			    image[i__ - 1] = 0;
-			}
+			image[i__ - 1] = iueton_(&zz) / 1000;
 		    }
 		}
 	    }
