@@ -1,13 +1,6 @@
-/*  -- translated by f2c (version 20050501).
-   You must link the resulting object file with libf2c:
-	on Microsoft Windows system, link with libf2c.lib;
-	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
-	or, if you install libf2c.a in a standard place, with -lf2c -lm
-	-- in that order, at the end of the command line, as in
-		cc *.o -lf2c -lm
-	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
-
-		http://www.netlib.org/f2c/libf2c.zip
+/* src/grph2/umpack/umfmap.f -- translated by f2c (version 20020621).
+   You must link the resulting object file with the libraries:
+	-lf2c -lm   (in that order)
 */
 
 #include "libtinyf2c.h"
@@ -21,7 +14,7 @@ static integer c__1 = 1;
 /* ----------------------------------------------------------------------- */
 /*     FILL PATTERN ON MAP (GEOGRAPHIC COORDINATE) */
 /* ----------------------------------------------------------------------- */
-/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
+/*     Copyright (C) 2000 GFD Dennou Club. All rights reserved. */
 /* ----------------------------------------------------------------------- */
 /* Subroutine */ int umfmap_(char *cdsn, ftnlen cdsn_len)
 {
@@ -39,38 +32,34 @@ static integer c__1 = 1;
 	    *, char *, ftnlen), e_rsue(void), f_clos(cllist *);
 
     /* Local variables */
-    static integer i__, iu, ios, igid;
+    static logical lfillake;
+    static integer ipatlake, ipatland, i__, iu, ios, igid;
     extern integer lenc_(char *, ftnlen);
     static char cmsg[80];
     static real xlat[8192], xlon[8192];
-    static integer npts;
+    static integer npts, index;
     static char cdsnx[80];
-    static integer ibgcli;
-    static logical lflake;
-    static integer iplake, ipland;
-    extern /* Subroutine */ int sgiget_(char *, integer *, ftnlen), msgdmp_(
-	    char *, char *, char *, ftnlen, ftnlen, ftnlen), umiget_(char *, 
-	    integer *, ftnlen), umlget_(char *, logical *, ftnlen), sgiset_(
-	    char *, integer *, ftnlen);
+    static integer itype;
+    extern /* Subroutine */ int msgdmp_(char *, char *, char *, ftnlen, 
+	    ftnlen, ftnlen), umiget_(char *, integer *, ftnlen), umlget_(char 
+	    *, logical *, ftnlen), sgiset_(char *, integer *, ftnlen);
     extern integer iufopn_(void);
     extern /* Subroutine */ int umqfnm_(char *, char *, ftnlen, ftnlen);
     static real xlatmn, xlonmn, xlatmx, xlonmx;
     extern /* Subroutine */ int sgtnzu_(integer *, real *, real *, integer *);
 
     /* Fortran I/O blocks */
-    static cilist io___9 = { 1, 0, 1, 0, 0 };
+    static cilist io___10 = { 1, 0, 1, 0, 0 };
 
 
 /*     / SET INTERNAL PARAMETERS / */
     sgiset_("IRMODE", &c__0, (ftnlen)6);
 /*     / GET INTERNAL PARAMETERS / */
-    sgiget_("IBGCLI", &ibgcli, (ftnlen)6);
-    umiget_("IPATLAND", &ipland, (ftnlen)8);
-    umiget_("IPATLAKE", &iplake, (ftnlen)8);
-    umlget_("LFILLAKE", &lflake, (ftnlen)8);
-    if (! lflake) {
-	iplake = ibgcli * 1000 + 999;
-    }
+    umiget_("INDEXOUT", &index, (ftnlen)8);
+    umiget_("ITYPEOUT", &itype, (ftnlen)8);
+    umiget_("IPATLAND", &ipatland, (ftnlen)8);
+    umiget_("IPATLAKE", &ipatlake, (ftnlen)8);
+    umlget_("LFILLAKE", &lfillake, (ftnlen)8);
 /*     / INQUIRE OUTLINE FILE / */
     umqfnm_(cdsn, cdsnx, cdsn_len, (ftnlen)80);
     if (s_cmp(cdsnx, " ", (ftnlen)80, (ftnlen)1) == 0) {
@@ -99,8 +88,8 @@ static integer c__1 = 1;
     f_rew(&al__1);
 /*     / READ OUTLINE DATA AND PLOT / */
 L10:
-    io___9.ciunit = iu;
-    ios = s_rsue(&io___9);
+    io___10.ciunit = iu;
+    ios = s_rsue(&io___10);
     if (ios != 0) {
 	goto L100001;
     }
@@ -146,10 +135,12 @@ L100001:
 		npts / 2 - 1]) {
 	    if (igid == 1) {
 		i__2 = npts / 2;
-		sgtnzu_(&i__2, xlon, xlat, &ipland);
+		sgtnzu_(&i__2, xlon, xlat, &ipatland);
 	    } else if (igid == 2) {
-		i__2 = npts / 2;
-		sgtnzu_(&i__2, xlon, xlat, &iplake);
+		if (lfillake) {
+		    i__2 = npts / 2;
+		    sgtnzu_(&i__2, xlon, xlat, &ipatlake);
+		}
 	    }
 	}
     }
