@@ -1,13 +1,6 @@
-/*  -- translated by f2c (version 20090411).
-   You must link the resulting object file with libf2c:
-	on Microsoft Windows system, link with libf2c.lib;
-	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
-	or, if you install libf2c.a in a standard place, with -lf2c -lm
-	-- in that order, at the end of the command line, as in
-		cc *.o -lf2c -lm
-	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
-
-		http://www.netlib.org/f2c/libf2c.zip
+/* src/grph2/umpack/umspcw.f -- translated by f2c (version 20020621).
+   You must link the resulting object file with the libraries:
+	-lf2c -lm   (in that order)
 */
 
 #include "libtinyf2c.h"
@@ -70,12 +63,12 @@ static real c_b10 = 0.f;
 	    if (stlat1 == umwk1_1.rundef) {
 /* Computing MAX */
 		r__1 = ycntr - r__, r__2 = umwk1_1.cpd * -89.f;
-		stlat1 = max(r__1,r__2);
+		stlat1 = dmax(r__1,r__2);
 	    }
 	    if (stlat2 == umwk1_1.rundef) {
 /* Computing MIN */
 		r__1 = ycntr + r__, r__2 = umwk1_1.cpd * 89.f;
-		stlat2 = min(r__1,r__2);
+		stlat2 = dmin(r__1,r__2);
 	    }
 	    sgrset_("STLAT1", &stlat1, (ftnlen)6);
 	    sgrset_("STLAT2", &stlat2, (ftnlen)6);
