@@ -1,13 +1,6 @@
-/*  -- translated by f2c (version 20050501).
-   You must link the resulting object file with libf2c:
-	on Microsoft Windows system, link with libf2c.lib;
-	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
-	or, if you install libf2c.a in a standard place, with -lf2c -lm
-	-- in that order, at the end of the command line, as in
-		cc *.o -lf2c -lm
-	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
-
-		http://www.netlib.org/f2c/libf2c.zip
+/* src/math1/lrllib/lreqa.f -- translated by f2c (version 20020621).
+   You must link the resulting object file with the libraries:
+	-lf2c -lm   (in that order)
 */
 
 #include "libtinyf2c.h"
@@ -23,7 +16,7 @@ logical lreqa_(real *x, real *y, real *epsl)
     real r__1;
     logical ret_val;
 
-    ret_val = (r__1 = *x - *y, abs(r__1)) <= *epsl;
+    ret_val = (r__1 = *x - *y, dabs(r__1)) <= *epsl;
     return ret_val;
 } /* lreqa_ */
 
