@@ -1,13 +1,6 @@
-/*  -- translated by f2c (version 20050501).
-   You must link the resulting object file with libf2c:
-	on Microsoft Windows system, link with libf2c.lib;
-	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
-	or, if you install libf2c.a in a standard place, with -lf2c -lm
-	-- in that order, at the end of the command line, as in
-		cc *.o -lf2c -lm
-	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
-
-		http://www.netlib.org/f2c/libf2c.zip
+/* src/math1/maplib/mpzktd.f -- translated by f2c (version 20020621).
+   You must link the resulting object file with the libraries:
+	-lf2c -lm   (in that order)
 */
 
 #include "libtinyf2c.h"
@@ -24,7 +17,7 @@
 
     /* Local variables */
     static real b, pi;
-    extern real rfpi_(void);
+    extern doublereal rfpi_(void);
 
     pi = rfpi_();
     b = pi * 2 / 3.f + .86602539999999995f;
