@@ -1,13 +1,6 @@
-/*  -- translated by f2c (version 20050501).
-   You must link the resulting object file with libf2c:
-	on Microsoft Windows system, link with libf2c.lib;
-	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
-	or, if you install libf2c.a in a standard place, with -lf2c -lm
-	-- in that order, at the end of the command line, as in
-		cc *.o -lf2c -lm
-	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
-
-		http://www.netlib.org/f2c/libf2c.zip
+/* src/math1/rfalib/rstd.f -- translated by f2c (version 20020621).
+   You must link the resulting object file with the libraries:
+	-lf2c -lm   (in that order)
 */
 
 #include "libtinyf2c.h"
@@ -17,14 +10,14 @@
 /* ----------------------------------------------------------------------- */
 /*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
 /* ----------------------------------------------------------------------- */
-real rstd_(real *rx, integer *n, integer *jx)
+doublereal rstd_(real *rx, integer *n, integer *jx)
 {
     /* System generated locals */
     real ret_val;
 
     /* Local variables */
-    extern real rstd0_(real *, integer *, integer *), rstd1_(real *, integer *
-	    , integer *);
+    extern doublereal rstd0_(real *, integer *, integer *), rstd1_(real *, 
+	    integer *, integer *);
     static logical lmiss;
     extern /* Subroutine */ int gllget_(char *, logical *, ftnlen);
 
