@@ -1,13 +1,6 @@
-/*  -- translated by f2c (version 20050501).
-   You must link the resulting object file with libf2c:
-	on Microsoft Windows system, link with libf2c.lib;
-	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
-	or, if you install libf2c.a in a standard place, with -lf2c -lm
-	-- in that order, at the end of the command line, as in
-		cc *.o -lf2c -lm
-	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
-
-		http://www.netlib.org/f2c/libf2c.zip
+/* src/math1/rfalib/rvar1.f -- translated by f2c (version 20020621).
+   You must link the resulting object file with the libraries:
+	-lf2c -lm   (in that order)
 */
 
 #include "libtinyf2c.h"
@@ -15,7 +8,7 @@
 /* ----------------------------------------------------------------------- */
 /*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
 /* ----------------------------------------------------------------------- */
-real rvar1_(real *rx, integer *n, integer *jx)
+doublereal rvar1_(real *rx, integer *n, integer *jx)
 {
     /* System generated locals */
     integer i__1, i__2;
@@ -24,7 +17,7 @@ real rvar1_(real *rx, integer *n, integer *jx)
     /* Local variables */
     static integer i__, nn;
     static real ave, sum;
-    extern real rave1_(real *, integer *, integer *);
+    extern doublereal rave1_(real *, integer *, integer *);
     static real rmiss;
     extern /* Subroutine */ int glrget_(char *, real *, ftnlen);
 
